@@ -1,5 +1,7 @@
 at 'house';
 
-text "You are at the front door.";
+text q{
+	You are at the front door.
+};
 
 next_page living_room => 'Enter the house';
